==> teads_sdk_flutter-1.0.0.tar.gz: README.md <==


<br/>
<p align="center">
    <a href="https://teads.com/" target="_blank">
        <img width="75%" src="./ReadmeResources/teads_logo.png" alt="Teads logo">
    </a>
</p>
<br/>

----

Teads allows you to integrate a single SDK into your app, and serve premium branded "outstream" video ads from Teads SSP ad server. This sample app includes Teads Flutter framework and is showing integration examples.

## 📃 Table of Contents

- [Integration Documentation](#-integration-documentation)
- [Run the sample app](#-run-the-sample-app)
- [Installation](#-install-the-teads-sdk-ios-framework)
- [Certifications](#-certifications)
- [Changelog](#%EF%B8%8F-changelog)

## 🚀 Integration Documentation

Integration instructions are available on [Teads SDK Documentation](https://support.teads.tv/support/solutions/articles/36000314785).

## 🚲 Run the sample app

Clone this repository, open it with Android Studio, and run project.

## 📦 Install the Teads SDK Flutter framework

Teads SDK is currently distributed through Pub. It includes everything you need to serve "outstream" video ads.

### Using packages

To add the package, `teads_sdk_flutter`, to an app:

1. Depend on it
    - Open the pubspec.yaml file located inside the app folder, and add `teads_sdk_flutter`: under dependencies.
2. Install it
    - From the **terminal**: Run `flutter pub get`.<br>
      **OR**
    - From **Android Studio/IntelliJ**: Click Packages get in the action ribbon at the top of pubspec.yaml.<br>
      **OR**
    - From **VS Code**: Click Get Packages located in right side of the action ribbon at the top of pubspec.yaml.
3. Import it
    - Add a corresponding import statement in the Dart code.

## 🎓 Certifications

Teads SDK supports the [IAB](https://www.iabcertification.com/) [Open Measurement](https://iabtechlab.com/standards/open-measurement-sdk/) SDK, also known as OM SDK. The OM SDK brings transparency to the advertising world, giving a way to standardize the viewability and verification measurement for the ads served through mobile apps.  Teads is part of the [IAB's compliant companies](https://iabtechlab.com/compliance-programs/compliant-companies/).

![iab certification badge](./ReadmeResources/OMCompliant.png)


## ⌚️ Changelog

See [changelog here](https://github.com/teads/TeadsSDK-flutter/releases).

==> teads_sdk_flutter-1.0.3.tar.gz: README.md <==
<br/>
<p align="center">
    <a href="https://teads.com/" target="_blank">
        <img width="75%" src="https://raw.githubusercontent.com/teads/TeadsSDK-flutter/main/ReadmeResources/teads_logo.png" alt="Teads logo">
    </a>
</p>
<br/>

----

Teads allows you to integrate a single SDK into your app, and serve premium branded "outstream" video ads from Teads SSP ad server. This sample app includes Teads Flutter framework and is showing integration examples.

## 📃 Table of Contents

- [Integration Documentation](#-integration-documentation)
- [Run the sample app](#-run-the-sample-app)
- [Installation](#-install-the-teads-sdk-ios-framework)
- [Certifications](#-certifications)
- [Changelog](#%EF%B8%8F-changelog)

## 🚀 Integration Documentation

Integration instructions are available on [Teads SDK Documentation](https://support.teads.tv/support/solutions/36000157079).

## 🚲 Run the sample app

Clone this repository, open it with Android Studio, and run project.

## 📦 Install the Teads SDK Flutter framework

Teads SDK is currently distributed through Pub. It includes everything you need to serve "outstream" video ads.

### Using packages

To add the package, `teads_sdk_flutter`, to an app:

1. Depend on it
    - Open the pubspec.yaml file located inside the app folder, and add `teads_sdk_flutter`: under dependencies.
2. Install it
    - From the **terminal**: Run `flutter pub get`.<br>
      **OR**
    - From **Android Studio/IntelliJ**: Click Packages get in the action ribbon at the top of pubspec.yaml.<br>
      **OR**
    - From **VS Code**: Click Get Packages located in right side of the action ribbon at the top of pubspec.yaml.
3. Import it
    - Add a corresponding import statement in the Dart code.

## 🎓 Certifications

Teads SDK supports the [IAB](https://www.iabcertification.com/) [Open Measurement](https://iabtechlab.com/standards/open-measurement-sdk/) SDK, also known as OM SDK. The OM SDK brings transparency to the advertising world, giving a way to standardize the viewability and verification measurement for the ads served through mobile apps.  Teads is part of the [IAB's compliant companies](https://iabtechlab.com/compliance-programs/compliant-companies/).

![iab certification badge](https://raw.githubusercontent.com/teads/TeadsSDK-flutter/main/ReadmeResources/OMCompliant.png)


## ⌚️ Changelog

See [changelog here](https://github.com/teads/TeadsSDK-flutter/releases).
